@@ -15,7 +15,6 @@
 #include <kurl.h>
 #include "kitasubjectviewbase.h"
 
-class KitaModel;
 class Kita;
 
 /**
@@ -27,17 +26,17 @@ class KitaSubjectView : public KitaSubjectViewBase
   Q_OBJECT
 
 public:
-  KitaSubjectView(QWidget *parent, Kita* _mainWindow, const char *name=0);
+  KitaSubjectView(QWidget *parent, const char *name=0);
   ~KitaSubjectView();
-  void setModel(KitaModel* _m);
-  void loadBoard(KURL url);
 public slots:
   void reloadSubject();
   void loadThread(QListViewItem* item);
+  void slotLoadBoard(const KURL& url, const QString& boardName);
 private: // Private attributes
-  KitaModel* model;
-  Kita* mainWindow;
-  KURL boardURL;
+  KURL m_boardURL;
+  QString m_boardName;
+signals:
+  void signalShowThread(const KURL& datURL, const KURL& boardURL, const QString& boardName);
 };
 
 #endif
